// Copyright 2007 by Intuit Inc.
// All rights reserved
// Usage governed by the QuickBooks SDK Developer's License Agreement

using System;
using System.Collections.Generic;
using System.Text;
using Interop.QBFC10;

namespace Intuit_QBFC1.Subscription_Framework.Menu
{
    public class SubMenuType : IMenuBuilder
    {
        private ENVisibleIf[] _visibleIf = new ENVisibleIf[0];
        private ENVisibleIfNot[] _visibleIfNot = new ENVisibleIfNot[0];
        private ENEnabledIf[] _enableIf = new ENEnabledIf[0];
        private ENEnabledIfNot[] _enableIfNot = new ENEnabledIfNot[0];
        private MenuItemType[] _menuItems = new MenuItemType[0];

        // Don't allow calls to the default constructor
        private SubMenuType() { }

        /// <summary>
        /// With this type of menu, your application name appears at a predefined location in 
        /// the QuickBooks menu and is followed by a right arrow that opens the submenu. 
        /// The subitems (the list of MenuItem objects) show up in the order in which they 
        /// are specified in the Submenu object.
        /// </summary>
        /// <param name="menuItems">An array of MenuItems to display</param>
        public SubMenuType(MenuItemType[] menuItems)
        {
            if (menuItems == null)
                throw new Exception("Error: you must have at least one MenuItem");

            _menuItems = menuItems;
        }

        /// <summary>
        /// Allows setting and getting of the VisibleIF condition
        /// </summary>
        public ENVisibleIf[] VisibleIf
        {
            get
            {
                return _visibleIf;
            }
            set
            {
                _visibleIf = value;
            }
        }

        /// <summary>
        /// Allows setting and getting of the Visible IF NOT condition
        /// </summary>
        public ENVisibleIfNot[] VisibleIfNot
        {
            get
            {
                return _visibleIfNot;
            }
            set
            {
                _visibleIfNot = value;
            }
        }

        /// <summary>
        /// Allows setting and getting of the Enable IF condition
        /// </summary>
        public ENEnabledIf[] EnabledIf
        {
            get
            {
                return _enableIf;
            }
            set
            {
                _enableIf = value;
            }
        }

        /// <summary>
        /// Allows setting and getting of the Enable IF NOT condition
        /// </summary>
        public ENEnabledIfNot[] EnabledIfNot
        {
            get
            {
                return _enableIfNot;
            }
            set
            {
                _enableIfNot = value;
            }
        }

        /// <summary>
        /// Provides r/o access to the embedded menu items
        /// </summary>
        public MenuItemType[] MenuItems
        {
            get
            {
                return _menuItems;
            }
        }
    }
}
